JunnyDialogConfig class

Junny基础对话框配置

用于配置对话框的显示样式、动画、交互等属性。

示例:

final config = JunnyDialogConfig(
  builder: (context) => Text('对话框内容'),
  alignment: Alignment.center,
  clickMaskDismiss: true,
);

JunnyDialogUtils.instance.show(config);
Annotations

Constructors

JunnyDialogConfig({WidgetBuilder? builder, SmartDialogController? controller, Alignment? alignment, bool? clickMaskDismiss, SmartAnimationType? animationType, List<SmartNonAnimationType>? nonAnimationTypes, Widget animationBuilder(AnimationController controller, Widget child, AnimationParam animationParam)?, bool? usePenetrate, bool? useAnimation, Duration? animationTime, Color? maskColor, Widget? maskWidget, VoidCallback? onMask, bool? debounce, VoidCallback? onDismiss, Duration? displayTime, String? tag, bool? keepSingle, bool? permanent, bool? useSystem, bool? bindPage, BuildContext? bindWidget, Rect? ignoreArea, SmartBackType? backType, FutureOr<bool> onBack()?})
const

Properties

alignment Alignment?
对话框位置对齐方式
final
animationBuilder Widget Function(AnimationController controller, Widget child, AnimationParam animationParam)?
自定义动画构建器
final
animationTime Duration?
动画时长
final
animationType SmartAnimationType?
动画类型
final
backType SmartBackType?
返回按键类型
final
bindPage bool?
是否绑定页面
final
bindWidget BuildContext?
绑定组件
final
builder WidgetBuilder?
对话框内容构建器
final
clickMaskDismiss bool?
点击遮罩是否关闭
final
controller SmartDialogController?
对话框控制器
final
debounce bool?
是否防抖
final
displayTime Duration?
显示时长
final
hashCode int
The hash code for this object.
no setteroverride
ignoreArea Rect?
忽略区域
final
keepSingle bool?
是否保持单例
final
maskColor Color?
遮罩颜色
final
maskWidget Widget?
遮罩组件
final
nonAnimationTypes List<SmartNonAnimationType>?
非动画类型列表
final
onBack FutureOr<bool> Function()?
返回按键回调
final
onDismiss VoidCallback?
关闭回调
final
onMask VoidCallback?
点击遮罩回调
final
permanent bool?
是否永久显示
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tag String?
标签
final
useAnimation bool?
是否使用动画
final
usePenetrate bool?
是否允许穿透
final
useSystem bool?
是否使用系统对话框
final

Methods

copyWith({WidgetBuilder? builder, SmartDialogController? controller, Alignment? alignment, bool? clickMaskDismiss, SmartAnimationType? animationType, List<SmartNonAnimationType>? nonAnimationTypes, Widget animationBuilder(AnimationController controller, Widget child, AnimationParam animationParam)?, bool? usePenetrate, bool? useAnimation, Duration? animationTime, Color? maskColor, Widget? maskWidget, VoidCallback? onMask, bool? debounce, VoidCallback? onDismiss, Duration? displayTime, String? tag, bool? keepSingle, bool? permanent, bool? useSystem, bool? bindPage, BuildContext? bindWidget, Rect? ignoreArea, SmartBackType? backType, FutureOr<bool> onBack()?}) JunnyDialogConfig
创建一个新的配置实例,可选择性地覆盖当前值
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override