JunnyLoadingDialogConfig class

Loading对话框配置

用于配置Loading对话框的显示样式、交互等属性。

示例:

final config = JunnyLoadingDialogConfig(
  message: '加载中...',
  clickMaskDismiss: false,
  priority: LoadingPriority.high,
);

JunnyDialogUtils.instance.showLoading(config: config);
Annotations

Constructors

JunnyLoadingDialogConfig({bool clickMaskDismiss = false, SmartBackType backType = SmartBackType.block, Duration? displayTime, Color maskColor = Colors.transparent, LoadingPriority priority = LoadingPriority.normal, String? message, Widget builder(BuildContext context, {String? message})?})
创建Loading对话框配置
const
JunnyLoadingDialogConfig.fromJson(String source)
factory
JunnyLoadingDialogConfig.fromMap(Map<String, dynamic> map)
factory

Properties

backType SmartBackType
返回键行为
final
builder Widget Function(BuildContext context, {String? message})?
自定义loading构建器
final
clickMaskDismiss bool
点击遮罩是否关闭
final
displayTime Duration?
显示时长
final
hashCode int
The hash code for this object.
no setteroverride
maskColor Color
遮罩颜色
final
message String?
默认提示文本
final
priority LoadingPriority
优先级
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({bool? clickMaskDismiss, SmartBackType? backType, Duration? displayTime, Color? maskColor, LoadingPriority? priority, String? message}) JunnyLoadingDialogConfig
创建一个新的配置实例,可选择性地覆盖当前值
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(covariant JunnyLoadingDialogConfig other) bool
The equality operator.
override