QueueList<E> class

A class that efficiently implements both Queue and List.

Implemented types
Mixed-in types
Available extensions

Constructors

QueueList([int? initialCapacity])
Creates an empty queue.
QueueList.from(Iterable<E> source)
Create a queue initially containing the elements of source.
factory

Properties

average double

Available on Iterable<num>, provided by the IterableNumberExtension extension

The arithmetic mean of the elements of a non-empty iterable.
no setter
average double

Available on Iterable<int>, provided by the IterableIntegerExtension extension

The arithmetic mean of the elements of a non-empty iterable.
no setter
first ↔ E
The first element.
getter/setter pairinherited
firstOrNull → T?

Available on Iterable<T>, provided by the IterableExtension extension

The first element, or null if the iterable is empty.
no setter
firstOrNull → T?

Available on Iterable<T>, provided by the IterableExtensions extension

The first element of this iterator, or null if the iterable is empty.
no setter
flattened Iterable<T>

Available on Iterable<Iterable<T>>, provided by the IterableIterableExtension extension

The sequential elements of each iterable in this iterable.
no setter
flattenedToList List<T>

Available on Iterable<Iterable<T>>, provided by the IterableIterableExtension extension

The sequential elements of each iterable in this iterable.
no setter
flattenedToSet Set<T>

Available on Iterable<Iterable<T>>, provided by the IterableIterableExtension extension

The unique sequential elements of each iterable in this iterable.
no setter
hashCode int
The hash code for this object.
no setterinherited
indexed Iterable<(int, T)>

Available on Iterable<T>, provided by the IterableExtensions extension

Pairs of elements of the indices and elements of this iterable.
no setter
indexes Set<int>

Available on Iterable<E>, provided by the JunnyIterableExtension extension

获取当前迭代器所有元素的索引集合。
no setter
isEmpty bool
Whether this collection has no elements.
no setterinherited
isNotEmpty bool
Whether this collection has at least one element.
no setterinherited
iterator Iterator<E>
A new Iterator that allows iterating the elements of this Iterable.
no setterinherited
last ↔ E
The last element.
getter/setter pairinherited
lastOrNull → T?

Available on Iterable<T>, provided by the IterableExtension extension

The last element, or null if the iterable is empty.
no setter
lastOrNull → T?

Available on Iterable<T>, provided by the IterableExtensions extension

The last element of this iterable, or null if the iterable is empty.
no setter
length int
The number of elements in this Iterable.
getter/setter pairoverride
longestCommonPrefix String?

Available on List<String>, provided by the LongestCommonStringExtension extension

获取字符串列表的最长公共前缀。
no setter
longestCommonString String?

Available on List<String>, provided by the LongestCommonStringExtension extension

获取字符串列表的最长公共字符串。
no setter
max num

Available on Iterable<num>, provided by the IterableNumberExtension extension

A maximal element of the iterable.
no setter
max → T

Available on Iterable<T>, provided by the IterableComparableExtension extension

A maximal element of the iterable.
no setter
max int

Available on Iterable<int>, provided by the IterableIntegerExtension extension

A maximal element of the iterable.
no setter
max double

Available on Iterable<double>, provided by the IterableDoubleExtension extension

A maximal element of the iterable.
no setter
maxOrNull → T?

Available on Iterable<T>, provided by the IterableComparableExtension extension

A maximal element of the iterable, or null if the iterable is empty.
no setter
maxOrNull int?

Available on Iterable<int>, provided by the IterableIntegerExtension extension

A maximal element of the iterable, or null if the iterable is empty.
no setter
maxOrNull double?

Available on Iterable<double>, provided by the IterableDoubleExtension extension

A maximal element of the iterable, or null if the iterable is empty.
no setter
maxOrNull num?

Available on Iterable<num>, provided by the IterableNumberExtension extension

A maximal element of the iterable, or null if the iterable is empty.
no setter
min → T

Available on Iterable<T>, provided by the IterableComparableExtension extension

A minimal element of the iterable.
no setter
min double

Available on Iterable<double>, provided by the IterableDoubleExtension extension

A minimal element of the iterable.
no setter
min int

Available on Iterable<int>, provided by the IterableIntegerExtension extension

A minimal element of the iterable.
no setter
min num

Available on Iterable<num>, provided by the IterableNumberExtension extension

A minimal element of the iterable.
no setter
minOrNull double?

Available on Iterable<double>, provided by the IterableDoubleExtension extension

A minimal element of the iterable, or null it the iterable is empty.
no setter
minOrNull int?

Available on Iterable<int>, provided by the IterableIntegerExtension extension

A minimal element of the iterable, or null it the iterable is empty.
no setter
minOrNull → T?

Available on Iterable<T>, provided by the IterableComparableExtension extension

A minimal element of the iterable, or null it the iterable is empty.
no setter
minOrNull num?

Available on Iterable<num>, provided by the IterableNumberExtension extension

A minimal element of the iterable, or null it the iterable is empty.
no setter
nonNulls Iterable<T>

Available on Iterable<T?>, provided by the NullableIterableExtensions extension

The non-null elements of this iterable.
no setter
reversed Iterable<E>
An Iterable of the objects in this list in reverse order.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
single → E
Checks that this iterable has only one element, and returns that element.
no setterinherited
singleOrNull → T?

Available on Iterable<T>, provided by the IterableExtensions extension

The single element of this iterator, or null.
no setter
singleOrNull → T?

Available on Iterable<T>, provided by the IterableExtension extension

The single element of the iterable, or null.
no setter
sum num

Available on Iterable<num>, provided by the IterableNumberExtension extension

The sum of the elements.
no setter
sum double

Available on Iterable<double>, provided by the IterableDoubleExtension extension

The sum of the elements.
no setter
sum int

Available on Iterable<int>, provided by the IterableIntegerExtension extension

The sum of the elements.
no setter
toJS JSArray<T>

Available on List<T>, provided by the ListToJSArray extension

Converts this List to a JSArray by either casting, unwrapping, or cloning the List.
no setter
toJSProxyOrRef JSArray<T>

Available on List<T>, provided by the ListToJSArray extension

Converts this List to a JSArray by either casting, unwrapping, or proxying the List.
no setter
wait Future<List<T>>

Available on Iterable<Future<T>>, provided by the FutureIterable extension

Waits for futures in parallel.
no setter

Methods

add(E element) → void
Adds value at the end of the queue.
override
addAll(Iterable<E> iterable) → void
Adds all elements of iterable at the end of the queue. The length of the queue is extended by the length of iterable.
override
addFirst(E element) → void
Adds value at the beginning of the queue.
override
addLast(E element) → void
Adds value at the end of the queue.
override
any(bool test(E element)) bool
Checks whether any element of this iterable satisfies test.
inherited
asMap() Map<int, E>
An unmodifiable Map view of this list.
inherited
asNameMap() Map<String, T>

Available on Iterable<T>, provided by the EnumByName extension

Creates a map from the names of enum values to the values.
binarySearch(E element, [int compare(E, E)?]) int

Available on List<E>, provided by the ListComparableExtensions extension

Returns the index of element in this sorted list.
binarySearch(E element, int compare(E, E)) int

Available on List<E>, provided by the ListExtensions extension

Returns the index of element in this sorted list.
binarySearchBy<K extends Comparable<K>>(E element, K keyOf(E element), [int start = 0, int? end]) int

Available on List<E>, provided by the ListExtensions extension

Returns the index of element in this sorted list.
binarySearchByCompare<K>(E element, K keyOf(E element), int compare(K, K), [int start = 0, int? end]) int

Available on List<E>, provided by the ListExtensions extension

Returns the index of element in this sorted list.
byIndex(int index) → T

Available on Iterable<T>, provided by the EnumByName extension

根据给定的索引 index 查找并返回对应的枚举值。
byName(String name) → T

Available on Iterable<T>, provided by the EnumByName extension

Finds the enum value in this list with name name.
cast<T>() QueueList<T>
Provides a view of this queue as a queue of R instances, if necessary.
override
clear() → void
Removes all objects from this list; the length of the list becomes zero.
inherited
contains(Object? element) bool
Whether the collection contains an element equal to element.
inherited
elementAt(int index) → E
Returns the indexth element.
inherited
elementAtOrNull(int index) → T?

Available on Iterable<T>, provided by the IterableExtensions extension

The element at position index of this iterable, or null.
elementAtOrNull(int index) → T?

Available on Iterable<T>, provided by the IterableExtension extension

The indexth element, or null if there is no such element.
elementAtOrNull(int index) → E?

Available on List<E>, provided by the ListExtensions extension

The indexth element, or null if there is no such element.
equals(List<E> other, [Equality<E> equality = const DefaultEquality()]) bool

Available on List<E>, provided by the ListExtensions extension

Whether other has the same elements as this list.
equalsTo(Iterable<E> others, {bool predict(dynamic data1, dynamic data2)?}) bool

Available on Iterable<E>, provided by the JunnyIterableExtension extension

深度比较两个集合的元素是否相等。
every(bool test(E element)) bool
Checks whether every element of this iterable satisfies test.
inherited
expand<T>(Iterable<T> f(E element)) Iterable<T>
Expands each element of this Iterable into zero or more elements.
inherited
expandIndexed<R>(Iterable<R> expand(int index, T element)) Iterable<R>

Available on Iterable<T>, provided by the IterableExtension extension

Expands each element and index to a number of elements in a new iterable.
expandIndexed<R>(Iterable<R> expand(int index, E element)) Iterable<R>

Available on List<E>, provided by the ListExtensions extension

Expands each element and index to a number of elements in a new iterable.
fillRange(int start, int end, [E? fill]) → void
Overwrites a range of elements with fillValue.
inherited
firstAnyValidate(Iterable<bool?> predictions(E data)) → E?

Available on Iterable<E>, provided by the JunnyIterableExtension extension

检查是否存在任意符合条件的数据。
firstDuplicateRowIndex<K>(K keyOf(T element)) int?

Available on List<T>, provided by the JunnyListExtension extension

检查列表中是否存在重复数据,并返回首个重复数据的索引。
firstWhere(bool test(E element), {E orElse()?}) → E
The first element that satisfies the given predicate test.
inherited
firstWhereIndexedOrNull(bool test(int index, T element)) → T?

Available on Iterable<T>, provided by the IterableExtension extension

The first element whose value and index satisfies test.
firstWhereOrNull(bool test(T element)) → T?

Available on Iterable<T>, provided by the IterableExtension extension

The first element satisfying test, or null if there are none.
fold<T>(T initialValue, T combine(T previousValue, E element)) → T
Reduces a collection to a single value by iteratively combining each element of the collection with an existing value
inherited
foldIndexed<R>(R initialValue, R combine(int index, R previous, T element)) → R

Available on Iterable<T>, provided by the IterableExtension extension

Combine the elements with a value and the current index.
followedBy(Iterable<E> other) Iterable<E>
Creates the lazy concatenation of this iterable and other.
inherited
forEach(void action(E element)) → void
Invokes action on each element of this iterable in iteration order.
inherited
forEachIndexed(void action(int index, T element)) → void

Available on Iterable<T>, provided by the IterableExtension extension

Takes an action for each element.
forEachIndexed(void action(int index, E element)) → void

Available on List<E>, provided by the ListExtensions extension

Takes an action for each element.
forEachIndexedWhile(bool action(int index, E element)) → void

Available on List<E>, provided by the ListExtensions extension

Takes an action for each element and index as long as desired.
forEachIndexedWhile(bool action(int index, T element)) → void

Available on Iterable<T>, provided by the IterableExtension extension

Takes an action for each element and index as long as desired.
forEachWhile(bool action(E element)) → void

Available on List<E>, provided by the ListExtensions extension

Takes an action for each element as long as desired.
forEachWhile(bool action(T element)) → void

Available on Iterable<T>, provided by the IterableExtension extension

Takes an action for each element as long as desired.
getRange(int start, int end) Iterable<E>
Creates an Iterable that iterates over a range of elements.
inherited
groupFoldBy<K, G>(K keyOf(T element), G combine(G? previous, T element)) Map<K, G>

Available on Iterable<T>, provided by the IterableExtension extension

Groups elements by keyOf then folds the elements in each group.
groupIndexedMapBy<K>(K keyOf(T element)) Map<K, Map<int, T>>

Available on List<T>, provided by the JunnyListExtension extension

按照元素通过 keyOf 函数生成的键值进行分组,且记录原始索引。
groupListsBy<K>(K keyOf(T element)) Map<K, List<T>>

Available on Iterable<T>, provided by the IterableExtension extension

Groups elements into lists by keyOf.
groupSetsBy<K>(K keyOf(T element)) Map<K, Set<T>>

Available on Iterable<T>, provided by the IterableExtension extension

Groups elements into sets by keyOf.
indexedGroup(Iterable<int> indexes) List<T>

Available on List<T>, provided by the JunnyListExtension extension

根据给定的索引集合 indexes 提取对应的元素,并返回结果列表。
indexesWhere(bool test(E element)) Set<int>

Available on Iterable<E>, provided by the JunnyIterableExtension extension

筛选符合条件 test 的元素索引集合。
indexOf(Object? element, [int start = 0]) int
The first index of element in this list.
inherited
indexWhere(bool test(E element), [int start = 0]) int
The first index in the list that satisfies the provided test.
inherited
insert(int index, E element) → void
Inserts element at position index in this list.
inherited
insertAll(int index, Iterable<E> iterable) → void
Inserts all objects of iterable at position index in this list.
inherited
isSorted([Comparator<T>? compare]) bool

Available on Iterable<T>, provided by the IterableComparableExtension extension

Whether the elements are sorted by the compare ordering.
isSorted(Comparator<T> compare) bool

Available on Iterable<T>, provided by the IterableExtension extension

Whether the elements are sorted by the compare ordering.
isSortedBy<K extends Comparable<K>>(K keyOf(T element)) bool

Available on Iterable<T>, provided by the IterableExtension extension

Whether the elements are sorted by their keyOf property.
isSortedByCompare<K>(K keyOf(T element), Comparator<K> compare) bool

Available on Iterable<T>, provided by the IterableExtension extension

Whether the elements are compare-sorted by their keyOf property.
join([String separator = ""]) String
Converts each element to a String and concatenates the strings.
inherited
joinElement([E? separator]) Iterable<E>

Available on Iterable<E>, provided by the JunnyIterableExtension extension

在两个元素之间插入 separator,生成新的迭代器。
lastBy<K>(K key(T)) Map<K, T>

Available on Iterable<T>, provided by the IterableExtension extension

Associates the elements in this by the value returned by key.
lastIndexOf(Object? element, [int? start]) int
The last index of element in this list.
inherited
lastIndexWhere(bool test(E element), [int? start]) int
The last index in the list that satisfies the provided test.
inherited
lastWhere(bool test(E element), {E orElse()?}) → E
The last element that satisfies the given predicate test.
inherited
lastWhereIndexedOrNull(bool test(int index, T element)) → T?

Available on Iterable<T>, provided by the IterableExtension extension

The last element whose index and value satisfies test.
lastWhereOrNull(bool test(T element)) → T?

Available on Iterable<T>, provided by the IterableExtension extension

The last element satisfying test, or null if there are none.
lowerBound(E element, [int compare(E, E)?]) int

Available on List<E>, provided by the ListComparableExtensions extension

Returns the index where element should be in this sorted list.
lowerBound(E element, int compare(E, E)) int

Available on List<E>, provided by the ListExtensions extension

Returns the index where element should be in this sorted list.
lowerBoundBy<K extends Comparable<K>>(E element, K keyOf(E), [int start = 0, int? end]) int

Available on List<E>, provided by the ListExtensions extension

Returns the index where element should be in this sorted list.
lowerBoundByCompare<K>(E element, K keyOf(E), int compare(K, K), [int start = 0, int? end]) int

Available on List<E>, provided by the ListExtensions extension

Returns the index where element should be in this sorted list.
map<T>(T f(E element)) Iterable<T>
The current elements of this iterable modified by toElement.
inherited
mapIndexed<R>(R convert(int index, T element)) Iterable<R>

Available on Iterable<T>, provided by the IterableExtension extension

Maps each element and its index to a new value.
mapIndexed<R>(R convert(int index, E element)) Iterable<R>

Available on List<E>, provided by the ListExtensions extension

Maps each element and its index to a new value.
none(bool test(T)) bool

Available on Iterable<T>, provided by the IterableExtension extension

Whether no element satisfies test.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
operateSameElement<T>(Iterable<E> otherIterable, bool condition(E item1, E item2), T operation(E originalItem, E otherItem)) Iterable<T>

Available on Iterable<E>, provided by the JunnyIterableExtension extension

查找满足条件的相同元素,对其进行操作后返回新的数据。
recursiveFilterBy(Iterable<E>? childrenGetter(E data), bool prediction(E data)) Iterable<E>

Available on Iterable<E>, provided by the JunnyIterableExtension extension

递归筛选符合 prediction 条件的元素。
recursiveFilterWithParent({required Iterable<E>? childrenGetter(E data), required E childrenSetter(E parent, Iterable<E> children), required bool prediction(E data), required bool parentEquals(E data1, E data2), E deepCopy(E original)?}) Iterable<E>

Available on Iterable<E>, provided by the JunnyIterableExtension extension

递归查询符合条件的数据,并返回此数据最近的父节点数据。
reduce(E combine(E previousValue, E element)) → E
Reduces a collection to a single value by iteratively combining elements of the collection using the provided function.
inherited
reduceIndexed(T combine(int index, T previous, T element)) → T

Available on Iterable<T>, provided by the IterableExtension extension

Combine the elements with each other and the current index.
remove(Object? element) bool
Removes the first occurrence of value from this list.
inherited
removeAt(int index) → E
Removes the object at position index from this list.
inherited
removeByIndex(Iterable<int> indexes) List<T>

Available on List<T>, provided by the JunnyListExtension extension

根据给定的索引集合 indexes 删除元素,并返回已删除的元素列表。
removeFirst() → E
Removes and returns the first element of this queue.
override
removeLast() → E
Removes and returns the last element of the queue.
override
removeRange(int start, int end) → void
Removes a range of elements from the list.
inherited
removeWhere(bool test(E element)) → void
Removes all objects from this list that satisfy test.
inherited
replaceRange(int start, int end, Iterable<E> newContents) → void
Replaces a range of elements with the elements of replacements.
inherited
request() Future<Map<Permission, PermissionStatus>>

Available on List<Permission>, provided by the PermissionListActions extension

Requests the user for access to these permissions, if they haven't already been granted before.
retainWhere(bool test(E element)) → void
Removes all objects from this list that fail to satisfy test.
inherited
retype<T>() QueueList<T>
reverseRange(int start, int end) → void

Available on List<E>, provided by the ListExtensions extension

Reverses the elements in a range of the list.
sample(int count, [Random? random]) List<T>

Available on Iterable<T>, provided by the IterableExtension extension

Selects count elements at random from this iterable.
setAll(int index, Iterable<E> iterable) → void
Overwrites elements with the objects of iterable.
inherited
setRange(int start, int end, Iterable<E> iterable, [int skipCount = 0]) → void
Writes some elements of iterable into a range of this list.
inherited
shuffle([Random? random]) → void
Shuffles the elements of this list randomly.
inherited
shuffled([Random? random]) List<T>

Available on Iterable<T>, provided by the IterableExtension extension

Creates a shuffled list of the elements of the iterable.
shuffleRange(int start, int end, [Random? random]) → void

Available on List<E>, provided by the ListExtensions extension

Shuffle a range of elements.
singleWhere(bool test(E element), {E orElse()?}) → E
The single element that satisfies test.
inherited
singleWhereIndexedOrNull(bool test(int index, T element)) → T?

Available on Iterable<T>, provided by the IterableExtension extension

The single element satisfying test.
singleWhereOrNull(bool test(T element)) → T?

Available on Iterable<T>, provided by the IterableExtension extension

The single element satisfying test.
skip(int count) Iterable<E>
Creates an Iterable that provides all but the first count elements.
inherited
skipWhile(bool test(E element)) Iterable<E>
Creates an Iterable that skips leading elements while test is satisfied.
inherited
slice(int start, [int? end]) ListSlice<E>

Available on List<E>, provided by the ListExtensions extension

A fixed length view of a range of this list.
slices(int length) Iterable<List<E>>

Available on List<E>, provided by the ListExtensions extension

Contiguous slices of this with the given length.
slices(int length) Iterable<List<T>>

Available on Iterable<T>, provided by the IterableExtension extension

Contiguous slices of this with the given length.
sort([int compare(E a, E b)?]) → void
Sorts this list according to the order specified by the compare function.
inherited
sortBy<K extends Comparable<K>>(K keyOf(E element), [int start = 0, int? end]) → void

Available on List<E>, provided by the ListExtensions extension

Sorts elements by the natural order of their keyOf property.
sortByCompare<K>(K keyOf(E element), int compare(K a, K b), [int start = 0, int? end]) → void

Available on List<E>, provided by the ListExtensions extension

Sorts elements by the compare of their keyOf property.
sorted([Comparator<T>? compare]) List<T>

Available on Iterable<T>, provided by the IterableComparableExtension extension

Creates a sorted list of the elements of the iterable.
sorted(Comparator<T> compare) List<T>

Available on Iterable<T>, provided by the IterableExtension extension

Creates a sorted list of the elements of the iterable.
sortedBy<K extends Comparable<K>>(K keyOf(T element)) List<T>

Available on Iterable<T>, provided by the IterableExtension extension

Creates a sorted list of the elements of the iterable.
sortedByCompare<K>(K keyOf(T element), Comparator<K> compare) List<T>

Available on Iterable<T>, provided by the IterableExtension extension

Creates a sorted list of the elements of the iterable.
sortRange(int start, int end, int compare(E a, E b)) → void

Available on List<E>, provided by the ListExtensions extension

Sort a range of elements by compare.
sortRange(int start, int end, [int compare(E a, E b)?]) → void

Available on List<E>, provided by the ListComparableExtensions extension

Sort a range of elements by compare.
splitAfter(bool test(T element)) Iterable<List<T>>

Available on Iterable<T>, provided by the IterableExtension extension

Splits the elements into chunks after some elements.
splitAfterIndexed(bool test(int index, T element)) Iterable<List<T>>

Available on Iterable<T>, provided by the IterableExtension extension

Splits the elements into chunks after some elements and indices.
splitBefore(bool test(T element)) Iterable<List<T>>

Available on Iterable<T>, provided by the IterableExtension extension

Splits the elements into chunks before some elements.
splitBeforeIndexed(bool test(int index, T element)) Iterable<List<T>>

Available on Iterable<T>, provided by the IterableExtension extension

Splits the elements into chunks before some elements and indices.
splitBetween(bool test(T first, T second)) Iterable<List<T>>

Available on Iterable<T>, provided by the IterableExtension extension

Splits the elements into chunks between some elements.
splitBetweenIndexed(bool test(int index, T first, T second)) Iterable<List<T>>

Available on Iterable<T>, provided by the IterableExtension extension

Splits the elements into chunks between some elements and indices.
sublist(int start, [int? end]) List<E>
Returns a new list containing the elements between start and end.
inherited
swap(int index1, int index2) → void

Available on List<E>, provided by the ListExtensions extension

Swaps two elements of this list.
take(int count) Iterable<E>
Creates a lazy iterable of the count first elements of this iterable.
inherited
takeWhile(bool test(E element)) Iterable<E>
Creates a lazy iterable of the leading elements satisfying test.
inherited
toList({bool growable = true}) List<E>
Creates a List containing the elements of this Iterable.
inherited
toSet() Set<E>
Creates a Set containing the same elements as this iterable.
inherited
toString() String
A string representation of this object.
override
where(bool test(E element)) Iterable<E>
Creates a new lazy Iterable with all elements that satisfy the predicate test.
inherited
whereIndexed(bool test(int index, E element)) Iterable<E>

Available on List<E>, provided by the ListExtensions extension

The elements whose value and index satisfies test.
whereIndexed(bool test(int index, T element)) Iterable<T>

Available on Iterable<T>, provided by the IterableExtension extension

The elements whose value and index satisfies test.
whereNot(bool test(T element)) Iterable<T>

Available on Iterable<T>, provided by the IterableExtension extension

The elements that do not satisfy test.
whereNotIndexed(bool test(int index, E element)) Iterable<E>

Available on List<E>, provided by the ListExtensions extension

The elements whose value and index do not satisfy test.
whereNotIndexed(bool test(int index, T element)) Iterable<T>

Available on Iterable<T>, provided by the IterableExtension extension

The elements whose value and index do not satisfy test.
whereNotNull() Iterable<T>

Available on Iterable<T?>, provided by the IterableNullableExtension extension

The non-null elements of this Iterable.
whereType<T>() Iterable<T>
Creates a new lazy Iterable with all elements that have type T.
inherited

Operators

operator +(List<E> other) List<E>
Returns the concatenation of this list and other.
inherited
operator ==(Object other) bool
The equality operator.
inherited
operator [](int index) → E
The object at the given index in the list.
override
operator []=(int index, E value) → void
Sets the value at the given index in the list to value.
override