junny_form
library
Classes
AddressPicker
AddressPicker: 用于选择和管理地址信息的组件
AnimationParam
advanced usage:
ArcClipper
AttachAdjustParam
AttachmentTapParams
附件选择参数
AttachParam
Bidi
This provides utility methods for working with bidirectional text. All
of the methods are static, and are organized into a class primarily to
group them together for documentation and discoverability.
BidiFormatter
Bidi stands for Bi-directional text. According to
Wikipedia :
Bi-directional text is text containing text in both text directionalities,
both right-to-left (RTL) and left-to-right (LTR). It generally involves text
containing different types of alphabets, but may also refer to
boustrophedon, which is changing text directionality in each row.
BoolList
A space-efficient list of boolean values.
CalendarBuilders <T >
Class containing all custom builders for TableCalendar.
CalendarStyle
Class containing styling and configuration for TableCalendar's content.
CanonicalizedMap <C , K , V >
A map whose keys are converted to canonical values of type C.
CaseInsensitiveEquality
String equality that's insensitive to differences in ASCII case.
CheckableListTile
一个功能丰富的可选中列表项组件,支持自定义交互和布局
ChipsTapParams <T extends Object >
多选 Chips 选择字段参数
ChoiceTapParams <T extends Object >
单选字段参数
ClosedRange
闭区间指的是区间边界的两个值包括在内
格式为:min,max
例如:1, 2表示:1 <= x <= 2
CombinedIterableView <T >
A view of several iterables combined sequentially into a single iterable.
CombinedListView <T >
A view of several lists combined into a single list.
CombinedMapView <K , V >
Returns a new map that represents maps flattened into a single map.
CombiningSpanExtent
Runs the result of two SpanExtent s through a combiner function
to determine the ultimate pixel extent of a span.
CommonEmptyWidget
通用列表空页面
DateFormat
DateFormat is for formatting and parsing dates in a locale-sensitive
manner.
DateTimeNotifier
DateProvider is a ChangeNotifier that manages two DateTime objects:
_selectedDate and _focusedDate. These dates can be null initially.
DateTimePicker
日期时间选择器组件
支持多种时间选择模式,允许自定义初始时间范围、语言代码等
DateTimeRangePicker
日期区间选择器组件
支持选择开始时间和结束时间,并处理各种初始状态
DayPeriodConfig
dayPeriod 模式下的整体配置
DayPeriodHalfDefinition
单个半程的配置定义
DayPeriodSelectedHalf
当前选择的半程信息
DaysOfWeekStyle
Class containing styling for TableCalendar's days of week panel.
DecadeView
展示每十年为一组用于选择年份的控件
DeepCollectionEquality
Deep equality on collections.
DefaultEquality <E >
Equality of objects that compares only the natural equality of the objects.
DelegatingIterable <E >
An Iterable that delegates all operations to a base iterable.
DelegatingList <E >
A List that delegates all operations to a base list.
DelegatingMap <K , V >
A Map that delegates all operations to a base map.
DelegatingQueue <E >
A Queue that delegates all operations to a base queue.
DelegatingSet <E >
A Set that delegates all operations to a base set.
DeveloperModeListener
开发者模式监听器组件
DeviceUtils
设备相关的工具类,提供获取设备信息的方法
DirectoryUtils
文件夹相关的工具类,提供初始化存储目录等方法
在调用任何目录获取方法之前,必须先调用 init 方法进行初始化。
EmptyTapParams
定义一个空参数实现
Equality <E >
A generic equality relation on objects.
EqualityBy <E , F >
Equality of objects based on derived values.
EqualityMap <K , V >
A Map whose key equality is determined by an Equality object.
EqualitySet <E >
A Set whose key equality is determined by an Equality object.
ExpandableInfoTile
用于展示信息的可点击展开的控件
ExpandableWidget
可展开/收起的通用组件
FixedSpanExtent
A span extent with a fixed pixels value.
FlutterSmartDialog
FlutterSmartNotifyStyle
FoldableActions
可折叠操作按钮组
FormFieldTypeConverter <F extends Object >
表单字段类型转换器
FormKeyValueTransformer
表单字段与数据键值转换器
FractionalSpanExtent
Specified the span extent as a fraction of the viewport extent.
HapticUtil
HapticUtil 是一个震动反馈工具类,提供了不同类型的震动反馈功能,
用于向用户提供成功、警告和失败等通知类型的震动反馈。该类通过震动序列
和平台适配,简化了震动反馈的调用,提升了用户交互体验。
Class containing styling and configuration of TableCalendar's header.
HeapPriorityQueue <E >
Heap based priority queue.
IdentityEquality <E >
Equality of objects that compares only the identity of the objects.
InkWrapper
水波纹点击控件
Intl
The Intl class provides a common entry point for internationalization
related tasks. An Intl instance can be created for a particular locale
and used to create a date format via anIntl.date(). Static methods
on this class are also used in message formatting.
IterableEquality <E >
Equality on iterables.
IterableZip <T >
Iterable that iterates over lists of values from other iterables.
JunnyAddressField
地址选择字段组件
JunnyAddressFieldState
地址选择字段状态管理类
JunnyAppbar
JunnyAttachedDialogConfig
Junny附加对话框配置
JunnyAttachmentField
自定义附件字段组件,用于处理附件选择和显示
JunnyAttachmentFieldState
附件选择字段状态管理类
JunnyChipsField <T extends Object >
多选 Chips 表单字段组件
JunnyChipsFieldState <T extends Object >
标签多选字段状态管理类
JunnyChoiceField <T extends Object >
单选数据表单字段组件
JunnyChoiceFieldState <T extends Object >
单选字段状态管理类
JunnyDateField
自定义日期字段组件,用于处理日期选择和显示
JunnyDateFieldState
日期选择字段状态管理类
JunnyDateTimeRange
这是日期时间范围的类定义
JunnyDateTimeRangeField
日期时间范围选择器表单字段
JunnyDateTimeRangeFieldState
日期时间范围选择字段状态管理类
JunnyDialogConfig
Junny基础对话框配置
JunnyDialogUtils
对话框工具类
JunnyDictChipsField
数据字典多选字段组件
JunnyDictChipsFieldState
数据字典多选字段状态管理类
JunnyDictDataField <T extends Object >
自定义数据字典字段组件,用于处理数据字典选择和显示
JunnyDictDataFieldState <T extends Object >
数据字典单选字段状态管理类
JunnyDictEnumField <T extends Object >
自定义数据字典字段组件,用于处理数据字典选择和显示
JunnyDictEnumFieldState <T extends Object >
枚举类型数据字典单选字段状态管理类
JunnyDictFieldState <T extends Object >
自定义数据字典字段组件,用于处理数据字典选择和显示
JunnyErrorWidget
错误界面
JunnyFormAddressParams
地址选择字段参数配置类
JunnyFormAttachmentParams
附件选择字段参数配置类
JunnyFormChipsParams <T extends Object >
标签多选字段参数配置类
JunnyFormChoiceParams <T extends Object >
非 Map 泛型 Choice 参数
JunnyFormController
JunnyFormController 用于集中管理表单数据和字段的异步验证错误状态。
每个表单字段的值存储在 _formData 中,字段的错误信息存储在 _errorMessages 中。
使用字段监听器可以观察特定字段的变化,避免整体刷新。
JunnyFormControlScope
表单控制作用域
JunnyFormDateParams
日期选择字段参数配置类
JunnyFormDateTimeRangeParams
日期时间范围选择字段参数配置类
JunnyFormDictChipsParams
数据字典多选字段参数配置类
JunnyFormDictDataParams <T extends Object >
数据字典数据字段参数配置类
JunnyFormDictEnumParams <T extends Object >
枚举类型数据字典字段参数配置类
JunnyFormDictParams <T extends Object >
数据字典字段参数配置类
JunnyFormField <T extends Object >
JunnyFormField 自定义表单字段,用于支持异步验证及复杂配置。
JunnyFormFieldBasicConfig <T >
Field basic configuration for form field identity and initial value
字段的基础配置,用于表单字段的标识、标题和初始值
JunnyFormFieldConfig <T extends Object ? >
Configuration for a form field, encapsulating basic, decoration, interaction, status, and validation settings
表单字段的配置,封装了基础、装饰、交互、状态和验证设置
JunnyFormFieldController
表单字段控制器
用于管理表单字段的值和错误状态,提供值的读写、错误管理和状态变化通知
JunnyFormFieldDecorationConfig <T >
A configuration class for customizing form field decorations in the Junny framework.
用于在Junny框架中自定义表单字段装饰的配置类
JunnyFormFieldFactory
JunnyFormFieldFactory 是一个用于动态创建表单字段的工厂类。
通过注册的构造函数,可以根据给定的配置生成具体的表单字段组件。
JunnyFormFieldInteractionConfig <T >
Configuration for managing form field interactions, including focus, taps,
and enabling/disabling states.
用于管理表单字段交互的配置,包括焦点控制、点击事件、启用/禁用状态等
JunnyFormFieldRegistry
JunnyFormFieldRegistry 是一个用于注册和管理表单字段构造函数的单例类。
JunnyFormFieldState <T extends Object >
表单字段状态基类
JunnyFormFieldStatusConfig <T >
Field status related configuration for handling value changes and validations
字段状态相关的配置,用于处理值变化和验证
JunnyFormFieldValidatorConfig <T >
Field validation related configuration for defining validators
字段验证相关的配置,用于定义验证器
JunnyFormFilterBar
筛选栏组件
JunnyFormGlobalConfig
全局表单字段配置类,用于为表单字段提供统一布局和样式。
JunnyFormInputParams <T extends Object >
Input 输入框参数配置类
JunnyFormMapChoiceParams
Map 专用 Choice 参数,支持 valueMapper/echoKeys
JunnyFormMapSelectionParams
Map 类型选择字段参数(包含 valueMapper/echoKeys)
JunnyFormMonthParams
月份选择字段参数配置类
JunnyFormNumParams
数字输入框参数配置类
JunnyFormNumRangeParams
数字范围字段参数配置类
JunnyFormQuarterParams
季度选择字段参数配置类
JunnyFormSelectionParams <T extends Object >
通用选择字段参数(非 Map 专用)
JunnyFormSubtableParams
子表单参数配置类
JunnyFormTimeParams
时间选择字段参数配置类
JunnyFormValidationErrors
表单校验错误消息类,提供符号化错误消息生成方法
JunnyFormValidationRules
表单校验规则类,提供纯布尔判断方法
JunnyFormValidatorBuilder <T >
表单校验器链式构建器
JunnyFormValidators
表单校验器类,提供 FormFieldValidator 函数和链式构建器
JunnyFormWeekParams
周选择字段参数配置类
JunnyFormWidgetParams <T extends Object >
Widget 自定义组件参数配置类
JunnyFormYearParams
年份选择字段参数配置类
JunnyGlobalWidgetConfig
配置类:全局组件的统一配置入口
JunnyInputFieldState <T extends Object >
输入框字段基类,提供通用的输入框状态管理功能
JunnyLoadingDialogConfig
Loading对话框配置
JunnyLoadingUtils
Loading事务管理器
用于管理应用中的所有loading展示逻辑,提供以下特性:
JunnyLogUtils
LogUtils 是一个日志工具类,用于记录和处理应用程序的运行日志。
JunnyMapChoiceFieldState
处理 Map 类型的 ChoiceField State
JunnyMonthField
自定义月份字段组件,用于处理月份选择和显示
JunnyMonthFieldState
月份选择字段状态管理类
JunnyNumberFieldState
数字输入字段状态管理类
JunnyNumberRangeFieldState
数字范围输入字段状态管理类
JunnyNumField
自定义数字字段组件,用于处理数字输入和编辑
JunnyNumRangeData
表单数值范围数据模型
JunnyNumRangeField
自定义数字范围字段组件,用于处理数字范围的输入和编辑
JunnyPermissionUtils
权限工具类,用于处理应用的权限请求、检查、管理等功能。
JunnyQuarterField
自定义季度字段组件,用于处理季度选择和显示
JunnyQuarterFieldState
季度选择字段状态管理类
JunnyResultWrapper <T >
结果包装,用于区分手动取消还是选择的 null
Junny区块标题组件
JunnySectionHeader 组件的主题配置数据类
JunnySelectionFieldState <T extends Object >
通用选择字段状态基类
JunnySingleSelectionField
单选数据表单字段组件
JunnySingleSelectionFieldState
单选数据表单字段组件状态
JunnySubtableField
子表表单字段组件
JunnySubtableFieldController
子表格字段控制器
JunnySubtableFieldState
子表字段状态管理类
JunnySubtableItemFieldValidator
子表项字段验证器
JunnySubtableItemInfo
子表项信息
JunnySubtableListPage
子表数据展示页面组件
JunnyTextField
自定义文本字段组件,用于处理字符串输入和编辑
JunnyTimeField
自定义时间选择器
JunnyTimeFieldState
时间选择字段状态管理类
JunnyToastConfig
Toast配置类
JunnyToastUtils
Toast工具类
JunnyTreeConfig
树形组件配置类
JunnyTreeController <T >
树形控制器封装类
JunnyTreeConverter
简化的树形数据转换器
JunnyTreeUtils
树形节点工具类
JunnyTreeView <T >
通用树形组件
JunnyValidationPatterns
表单校验模式配置类
JunnyWeekField
JunnyWeekField
JunnyWeekFieldState
周选择字段状态管理类
JunnyWidgetField <T extends Object >
自定义组件表单字段
JunnyWidgetFieldState <T extends Object >
自定义组件表单字段状态
JunnyYearField
自定义年份字段组件,用于处理年份选择和显示
JunnyYearFieldState
年份选择字段状态管理类
LabeledCheckbox
LabeledRadio <T >
LazyIndexedStack
A lazy-IndexedStack written by Alex Li 💙.
it lazily build children only when they are first activated.
LeftOpenRange
左开右闭区间指的是左边的边界值不包括在内,而右边的边界值包括在内
格式为:(min,max] # 取值不包括 min,但包括 max
例如:(1, 2]表示:1 < x <= 2
ListEquality <E >
Equality on lists.
ListSlice <E >
A list view of a range of another list.
LoadingDialog
LoadingEvent
Loading状态事件
LoadingTransaction
加载动画事务
LogEvent
LogEvent 表示一次日志记录的事件对象,包含日志时间、标签、消息以及堆栈信息。
MapEquality <K , V >
Equality on maps.
MapKeySet <E >
An unmodifiable Set view of the keys of a Map .
MapValueSet <K , V >
Creates a modifiable Set view of the values of a Map .
MaxSpanExtent
Returns the larger pixel extent of the two provided SpanExtent .
菜单项按钮配置
MicroMoney
Used primarily for currency formatting, this number-like class stores
millionths of a currency unit, typically as an Int64.
MinSpanExtent
Returns the smaller pixel extent of the two provided SpanExtent .
MonthPicker
月份选择器组件
MonthView
用于展示并选择月份的控件
MultiEquality <E >
Combines several equalities into a single equality.
NonGrowableListMixin <E >
Mixin class that implements a throwing version of all list operations that
change the List's length.
NonGrowableListView <E >
A fixed-length list.
NoScrollBehavior
NumberFormat
Provides the ability to format a number in a locale-specific way.
NumberParserBase <R >
NumRange
数字区间父类
OpenRange
开区间指的是区间边界的两个值不包括在内
格式为:(min, max)
例如:(1, 2)表示:1 < x < 2
OriginalValueIndicator
原始值指示器组件
用于显示和比较表单字段的当前值与原始值的差异
当值发生变化时,可以通过点击显示原始值
PackageUtils
用于管理与包相关的信息,如版本、构建号和应用名称。此类还可以用于检查更新
以及处理版本相关的操作。
Permission
Defines the permissions which can be checked and requested.
PermissionWithService
A special kind of permission, used to access a service.
Pick
A picked object holding the value (may be null) and giving access to useful parsing functions
PlatformAlertDialog
PlatformProgressIndicator
Progress Indicator. Used in loading data.
弹窗菜单
PositionedOffset
Helper class containing data for internal Positioned widget.
PrimaryButton
系统主要的按钮
PriorityQueue <E >
A priority queue is a priority based work-list of elements.
QuarterPicker
季度选择器组件
QuarterView
用于展示并选择季度的控件
QueueList <E >
A class that efficiently implements both Queue and List .
RemainingSpanExtent
Specifies that the span should occupy the remaining space in the viewport.
RenderTableViewport
A render object for viewing RenderBox es in a table format that extends in
both the horizontal and vertical dimensions.
RenderTreeViewport
A render object for viewing RenderBox es in a tree format that extends in
both the horizontal and vertical dimensions.
RequiredPick
A picked object holding the value (never null) and giving access to useful parsing functions
ReverseClosedRange
反向闭区间指的是区间边界的两个值包括在内
格式为:(min , max)的反区间
例如:(1, 2)的反区间为:(-∞, 1] U [2, +∞)
ReverseLeftOpenRange
反向左开右闭区间指的是左边的边界值不包括在内,而右边的边界值包括在内
格式为:(min , max]的反区间
例如:(1, 2]的反区间为:(-∞, 1] U (2, +∞)
ReverseOpenRange
反向开区间指的是区间边界的两个值不包括在内
格式为:min , max的反区间
例如:1, 2的反区间为:(-∞, 1) U (2, +∞)
ReverseRightOpenRange
反向左闭右开区间指的是左边的边界值包括在内,而右边的边界值不包括在内
格式为:[min , max)的反区间
例如:[1, 2)的反区间为:(-∞, 1) U [2, +∞)
RightOpenRange
左闭又开区间指的是左边的边界值包括在内,而右边的边界值不包括在内
格式为:[min,max) # 取值包括 min,但不包括 max
例如:[1, 2)表示:1 <= x < 2
RotateIcon
A widget representing a rotating expand/collapse button. The icon rotates
180 degrees when pressed, then reverts the animation on a second press.
The underlying icon is Icons.expand_more .
RoundedUnderlineTabIndicator
Used with TabBar.indicator to draw a horizontal line below the
selected tab.
SelectedDataProvider <T >
管理已选择数据的类
SelectionTapParams <T extends Object >
通用选择字段参数
SetEquality <E >
Equality of sets.
SlidingTransition
Sliding
SmartConfigAttach
showAttach() global config
SmartConfigCustom
show() global config
SmartConfigLoading
showLoading() global config
SmartConfigNotify
show() global config
SmartConfigToast
showToast() global config
SmartDialog
SmartDialogController
SmartDialog Controller
Span
Defines the extent, visual appearance, and gesture handling of a row or
column.
SpanBorder
Describes the border for a Span .
SpanDecoration
A decoration for a Span .
SpanDecorationPaintDetails
Provides the details of a given SpanDecoration for painting.
SpanExtent
Defines the extent of a Span .
SpanExtentDelegate
Delegate passed to SpanExtent.calculateExtent from the
RenderTableViewport during layout.
SpanPadding
Defines the leading and trailing padding values of a Span .
TableCalendar <T >
Highly customizable, feature-packed Flutter calendar with gestures, animations and multiple formats.
TableCalendarBase
TableCellBuilderDelegate
A delegate that supplies children for a TableViewport on demand using a
builder callback.
TableCellListDelegate
A delegate that supplies children for a TableViewport using an
explicit two dimensional array.
TableVicinity
The relative position of a child in a TableViewport in relation
to other children of the viewport, in terms of rows and columns.
TableView
A widget that displays a table, which can scroll in horizontal and vertical
directions.
TableViewCell
Creates a cell of the TableView , along with information regarding merged
cells and RepaintBoundary s.
TableViewParentData
Parent data structure used by RenderTableViewport .
TableViewport
A widget through which a portion of a Table of Widget children are viewed,
typically in combination with a TableView .
TapListener
TapParams
定义一个基础的参数接口
TextDirection
Represents directionality of text.
TextInputFormatterUtils
工具类,提供常用的文本输入格式化方法
ThemeButton
跟随系统色的按钮
TimePicker
透明的PageRoute
TreeLineContainer
树形连线容器
TreeLineContainerUtils
树形连线容器工具类
TreeRowBorder
Describes the border for a TreeRow .
TreeRowBuilderDelegate
A delegate that supplies nodes for a TreeViewport on demand using a
builder callback.
TreeVicinity
The position of a TreeRow in a TreeViewport in relation
to other children of the viewport.
TreeView <T >
A widget that displays TreeViewNode s that expand and collapse in a
vertically and horizontally scrolling TreeViewport .
TreeViewController
Enables control over the TreeViewNodes of a TreeView .
TreeViewIndentationType
The style of indentation for TreeViewNode s in a TreeView , as handled
by RenderTreeViewport .
TreeViewNode <T >
A data structure for configuring children of a TreeView .
TreeViewport
A widget through which a portion of a tree of TreeViewNode children are
viewed as rows, typically in combination with a TreeView .
UnionSet <E >
A single set that provides a view of the union over a set of sets.
UnionSetController <E >
A controller that exposes a view of the union of a collection of sets.
UnmodifiableListView <E >
An unmodifiable List view of another List.
UnmodifiableMapMixin <K , V >
Mixin class that implements a throwing version of all map operations that
change the Map.
UnmodifiableMapView <K , V >
View of a Map that disallow modifying the map.
UnmodifiableSetMixin <E >
Mixin class that implements a throwing version of all set operations that
change the Set.
UnmodifiableSetView <E >
An unmodifiable set.
UnorderedIterableEquality <E >
Equality of the elements of two iterables without considering order.
ValueListenableBuilder2 <A , B >
WatermarkPainter
水印绘制器
WheelPicker <T >
滚轮选择器
YearPicker
年份选择器组件
Functions
asType <T > (dynamic data , [dynamic key0 , dynamic key1 , dynamic key2 , dynamic key3 , dynamic key4 , dynamic key5 , dynamic key6 , dynamic key7 , dynamic key8 , dynamic key9 ])
→ T
解析基础数据类型
asTypeList <T > (dynamic data , [dynamic key0 , dynamic key1 , dynamic key2 , dynamic key3 , dynamic key4 , dynamic key5 , dynamic key6 , dynamic key7 , dynamic key8 , dynamic key9 ])
→ List <T >
解析列表类型数据
binarySearch <E > (List <E > sortedList , E value , {int compare (E , E )? })
→ int
Returns a position of the value in sortedList, if it is there.
compareAsciiLowerCase (String a , String b )
→ int
Compares a and b lexically, converting ASCII letters to lower case.
compareAsciiLowerCaseNatural (String a , String b )
→ int
Compares strings a and b according to lower-case
natural sort ordering .
compareAsciiUpperCase (String a , String b )
→ int
Compares a and b lexically, converting ASCII letters to upper case.
compareAsciiUpperCaseNatural (String a , String b )
→ int
Compares strings a and b according to upper-case
natural sort ordering .
compareNatural (String a , String b )
→ int
Compares strings a and b according to natural sort ordering .
equalsIgnoreAsciiCase (String a , String b )
→ bool
Checks if strings a and b differ only on the case of ASCII letters.
getWeekdayNumber (StartingDayOfWeek weekday )
→ int
Returns a numerical value associated with given weekday.
groupBy <S , T > (Iterable <S > values , T key (S ) )
→ Map <T , List <S > >
Groups the elements in values by the value returned by key.
hashIgnoreAsciiCase (String string )
→ int
Hash code for a string which is compatible with equalsIgnoreAsciiCase .
insertionSort <E > (List <E > elements , {int compare (E , E )?, int start = 0 , int ? end })
→ void
Sort a list between start (inclusive) and end (exclusive) using
insertion sort.
isDynamicEmpty (dynamic data )
→ bool
判断动态类型是否为空。
isSameDay (DateTime ? a , DateTime ? b )
→ bool
Checks if two DateTime objects are the same day.
Returns false if either of them is null.
lastBy <S , T > (Iterable <S > values , T key (S ) )
→ Map <T , S >
Associates the elements in values by the value returned by key.
lowerBound <E > (List <E > sortedList , E value , {int compare (E , E )? })
→ int
Returns the first position in sortedList that does not compare less than
value.
mapMap <K1 , V1 , K2 , V2 > (Map <K1 , V1 > map , {K2 key (K1 , V1 )?, V2 value (K1 , V1 )? })
→ Map <K2 , V2 >
Creates a new map from map with new keys and values.
maxBy <S , T > (Iterable <S > values , T orderBy (S ), {int compare (T , T )? })
→ S?
Returns the element of values for which orderBy returns the maximum
value.
mergeMaps <K , V > (Map <K , V > map1 , Map <K , V > map2 , {V value (V , V )? })
→ Map <K , V >
Returns a new map with all key/value pairs in both map1 and map2.
mergeSort <E > (List <E > elements , {int start = 0 , int ? end , int compare (E , E )? })
→ void
Sorts a list between start (inclusive) and end (exclusive) using the
merge sort algorithm.
minBy <S , T > (Iterable <S > values , T orderBy (S ), {int compare (T , T )? })
→ S?
Returns the element of values for which orderBy returns the minimum
value.
normalizeDate (DateTime date )
→ DateTime
Returns date in UTC format, without its time part.
openAppSettings ()
→ Future <bool >
Opens the app settings page.
pick (dynamic json , [Object ? arg0 , Object ? arg1 , Object ? arg2 , Object ? arg3 , Object ? arg4 , Object ? arg5 , Object ? arg6 , Object ? arg7 , Object ? arg8 , Object ? arg9 ])
→ Pick
Picks the value of a json-like dart data structure consisting of Maps,
Lists and objects at location arg0, arg1 ... arg9
pickDeep (dynamic json , List <Object > selector )
→ Pick
Picks the value of json by traversing the object along the values in
selector one by one
pickFromJson (String json , [Object ? arg0 , Object ? arg1 , Object ? arg2 , Object ? arg3 , Object ? arg4 , Object ? arg5 , Object ? arg6 , Object ? arg7 , Object ? arg8 , Object ? arg9 ])
→ Pick
Picks a values from a json String at location arg0, arg1...
reverse <E > (List <E > elements , [int start = 0 , int ? end ])
→ void
Reverses a list, or a part of a list, in-place.
run <ReturnType > (ReturnType operation () )
→ ReturnType
执行指定的操作并返回其结果。
separatedIterable <E > (Iterable <E > iterable , E separator )
→ Iterable <E >
separator iterable with separator.
shuffle (List elements , [int start = 0 , int ? end , Random ? random ])
→ void
Shuffles a list randomly.
stronglyConnectedComponents <T > (Map <T , Iterable <T > > graph )
→ List <Set <T > >
Returns the strongly connected components of graph, in topological
order.
toBeginningOfSentenceCase <T extends String ? > (T input , [String ? locale ])
→ T
Convert a string to beginning of sentence case, in a way appropriate to the
locale.
transitiveClosure <T > (Map <T , Iterable <T > > graph )
→ Map <T , Set <T > >
Returns the transitive closure of graph.
typeOf <T > ()
→ Type
获取泛型 T 的实际类型。
Typedefs
AsyncFieldValidator <T >
= Future <String ? > Function(T? value )
Field async validator
CombiningTableSpanExtent
= CombiningSpanExtent
Runs the result of two TableSpanExtent s through a combiner function
to determine the ultimate pixel extent of a span.
CombiningTreeRowExtent
= CombiningSpanExtent
Runs the result of two TreeRowExtent s through a combiner function
to determine the ultimate pixel height of a tree row.
DayBuilder
= Widget ? Function(BuildContext context , DateTime day )
Signature for a function that creates a widget for a given day.
DayPeriodLabelGetter
= String Function(BuildContext context , DayPeriodSelectedHalf selectedHalf )
半程文案构建方法
FieldConstructor <T extends Object >
= JunnyFormField <T > Function(Key ? key , JunnyFormFieldConfig <T? > config )
FieldConstructor 是一个函数类型,用于根据给定的配置实例化特定类型的 JunnyFormField 。
FixedTableSpanExtent
= FixedSpanExtent
A span extent with a fixed pixels value.
FixedTreeRowExtent
= FixedSpanExtent
A TreeRow with a fixed pixels height.
FlutterSmartLoadingBuilder
= Widget Function(String msg )
FlutterSmartStyleBuilder
= Widget Function(Widget child )
FlutterSmartToastBuilder
= Widget Function(String msg )
FocusedDayBuilder
= Widget ? Function(BuildContext context , DateTime day , DateTime focusedDay )
Signature for a function that creates a widget for a given day.
Additionally, contains the currently focused day.
FractionalTableSpanExtent
= FractionalSpanExtent
Specified the span extent as a fraction of the viewport extent.
FractionalTreeRowExtent
= FractionalSpanExtent
Specified the TreeRow height as a fraction of the viewport extent.
HighlightBuilder
= Widget ? Function(BuildContext context , DateTime day , bool isWithinRange )
Signature for a function that creates a background highlight for a given day.
JunnyOnValueChangedWithController <T >
= void Function(JunnyFormController formController , String fieldName , T? previousValue , T? newValue )
值变化后的业务处理回调(携带 JunnyFormController 上下文)
MarkerBuilder <T >
= Widget ? Function(BuildContext context , DateTime day , List <T > events )
Signature for a function that creates an event marker for a given day.
Contains a list of events associated with that day.
MaxTableSpanExtent
= MaxSpanExtent
Returns the larger pixel extent of the two provided TableSpanExtent .
MaxTreeRowExtent
= MaxSpanExtent
Returns the larger pixel extent of the two provided TreeRowExtent .
行级菜单参数构建器类型。
MinTableSpanExtent
= MinSpanExtent
Returns the smaller pixel extent of the two provided TableSpanExtent .
MinTreeRowExtent
= MinSpanExtent
Returns the smaller pixel extent of the two provided TreeRowExtent .
OnDaySelected
= void Function(DateTime selectedDay , DateTime focusedDay )
Signature for onDaySelected callback. Contains the selected day and focused day.
OnRangeSelected
= void Function(DateTime ? start , DateTime ? end , DateTime focusedDay )
Signature for onRangeSelected callback.
Contains start and end of the selected range, as well as currently focused day.
RemainingTableSpanExtent
= RemainingSpanExtent
Specifies that the span should occupy the remaining space in the viewport.
RemainingTreeRowExtent
= RemainingSpanExtent
Specifies that the row should occupy the remaining space in the viewport.
SingleMarkerBuilder <T >
= Widget ? Function(BuildContext context , DateTime day , T event )
Signature for a function that creates a single event marker for a given day.
Contains a single event associated with that day.
SpanExtentCombiner
= double Function(double , double )
Signature for a function that combines the result of two
SpanExtent.calculateExtent invocations.
TableSpan
= Span
Defines the extent, visual appearance, and gesture handling of a row or
column in a TableView .
TableSpanBorder
= SpanBorder
Describes the border for a TableSpan .
TableSpanBuilder
= TableSpan ? Function(int index )
Signature for a function that creates a TableSpan for a given index of row
or column in a TableView .
TableSpanDecoration
= SpanDecoration
A decoration for a TableSpan .
TableSpanDecorationPaintDetails
= SpanDecorationPaintDetails
Provides the details of a given TableSpanDecoration for painting.
TableSpanExtent
= SpanExtent
Defines the extent of a TableSpan .
TableSpanExtentCombiner
= SpanExtentCombiner
Signature for a function that combines the result of two
TableSpanExtent.calculateExtent invocations.
TableSpanExtentDelegate
= SpanExtentDelegate
Delegate passed to TableSpanExtent.calculateExtent from the
RenderTableViewport during layout.
TableSpanPadding
= SpanPadding
Defines the leading and trailing padding values of a TableSpan .
TableViewCellBuilder
= TableViewCell Function(BuildContext context , TableVicinity vicinity )
Signature for a function that creates a child TableViewCell for a given
TableVicinity in a TableView , but may return null.
TextFormatter
= String Function(DateTime date , dynamic locale )
Signature for a function returning text that can be localized and formatted with DateFormat.
TreeRow
= Span
Defines the extent, visual appearance, and gesture handling of a row in a
TreeView .
TreeRowDecoration
= SpanDecoration
A decoration for a TreeRow .
TreeRowDecorationPaintDetails
= SpanDecorationPaintDetails
Provides the details of a given TreeRowDecoration for painting.
TreeRowExtent
= SpanExtent
Defines the extent, or height, of a TreeRow .
TreeRowExtentCombiner
= SpanExtentCombiner
Signature for a function that combines the result of two
TreeRowExtent.calculateExtent invocations.
TreeRowExtentDelegate
= SpanExtentDelegate
Delegate passed to TreeSpanExtent.calculateExtent from the
RenderTreeViewport during layout.
TreeRowPadding
= SpanPadding
Defines the leading and trailing padding values of a TreeRow .
TreeVicinityToRowBuilder
= TreeRow Function(TreeVicinity )
Returns a TreeRow for the given TreeVicinity in the TreeView .
TreeViewNodeBuilder <T >
= Widget Function(BuildContext context , TreeViewNode <T > node , AnimationStyle toggleAnimationStyle )
Signature for a function that creates a Widget to represent the given
TreeViewNode in the TreeView .
TreeViewNodeCallback <T >
= void Function(TreeViewNode <T > node )
Signature for a function that is called when a TreeViewNode is toggled,
changing its expanded state.
TreeViewNodesAnimation
= ({int fromIndex , int toIndex , double value } )
Represents the animation of the children of a parent TreeViewNode that
are animating into or out of view.
TreeViewRowBuilder <T >
= TreeRow Function(TreeViewNode <T > node )
Signature for a function that creates a TreeRow for a given
TreeViewNode in a TreeView .
WheelPickerActionBarBuilder <T >
= Widget Function(List <T? > ? dataGetter () )
WheelPickerTitleBuilder <T >
= String Function(T t )