MonthPicker class
月份选择器组件
一个横向布局的年月选择器,具有以下特性:
- 左侧年份选择器,右侧月份选择器
- 支持设置默认日期 initialDate
- 可配置时间范围限制 minTime 和 maxTime
- 月份变化回调 onChanged
- 自动处理边界情况和非法输入
- 支持国际化显示月份名称
- 年月联动:切换年份时自动调整月份到有效范围
使用示例:
MonthPicker(
initialDate: DateTime.now(),
minTime: DateTime(2000),
maxTime: DateTime(2030),
onChanged: (date) => print('Selected: ${date.year}-${date.month}'),
)
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- MonthPicker
- Available extensions
Constructors
-
MonthPicker({Key? key, DateTime? initialDate, DateTime? minTime, DateTime? maxTime, ValueSetter<
DateTime> ? onChanged}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- initialDate → DateTime?
-
初始选择的日期
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- maxTime → DateTime?
-
可选择的最晚时间
final
- minTime → DateTime?
-
可选择的最早时间
final
-
onChanged
→ ValueSetter<
DateTime> ? -
月份选择变化的回调函数
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
buildPageRoute<
T> ({RouteSettings? settings, bool maintainState = true, bool fullscreenDialog = false, bool opaque = true}) → PageRoute< T> -
Available on Widget, provided by the JunnyWidgetExtension extension
构建PageRoute -
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< MonthPicker> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited