OriginalValueIndicator class
原始值指示器组件 用于显示和比较表单字段的当前值与原始值的差异 当值发生变化时,可以通过点击显示原始值
字段状态控制
支持根据字段的 enable 状态自动控制显示/隐藏:
- 当 respectFieldStatus 为 true 时,字段禁用时自动隐藏指示器,只读时仍显示
- 当 respectFieldStatus 为 false 时(默认),忽略字段状态,仅根据值变化显示
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- OriginalValueIndicator
- Available extensions
Constructors
Properties
- child → Widget?
-
==================== 属性 ====================
自定义显示的子组件
如果为null,则显示默认的眼睛图标
final
- formatter → String Function(dynamic value)?
-
自定义值的格式化方法
如果为null,则使用默认的toString()
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- listenKey → String
-
需要监听变化的表单字段key
final
- originalKey → String
-
存储原始值的key
final
- respectFieldStatus → bool
-
是否根据字段状态控制显示
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
build(
BuildContext context) → Widget -
==================== UI 构建方法 ====================
override
-
buildPageRoute<
T> ({RouteSettings? settings, bool maintainState = true, bool fullscreenDialog = false, bool opaque = true}) → PageRoute< T> -
Available on Widget, provided by the JunnyWidgetExtension extension
构建PageRoute -
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited