TreeLineContainerUtils class
树形连线容器工具类
提供便捷的方法来创建树形连线容器
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
wrapNode<
T> (TreeViewNode< T> node, Widget child, {required JunnyTreeConfig config, Color? lineColor, Color? parentLineColor, double? strokeWidth, bool? useParentDashedLine}) → Widget - 为节点创建带连线的容器